@@ -5,11 +5,9 @@ package Msql::Statement;
 @Msql::Statement::ISA = qw(DBI::st);
 
 use strict;
-use vars qw($OPTIMIZE $VERSION $AUTOLOAD);
+use vars qw($VERSION $AUTOLOAD);
 
-$VERSION = '1.2201';
-
-$OPTIMIZE = 0; # controls, which optimization we default to
+$VERSION = '1.2202';
 
 sub fetchrow ($) {
     my $self = shift;
@@ -134,11 +132,11 @@ sub unctrl {
     $x;
 }
 
+use vars qw($OPTIMIZE);
+$OPTIMIZE = 0;
 sub optimize {
     my($self,$arg) = @_;
-    if (defined $arg) {
-	$OPTIMIZE = $arg;
-    }
+    $OPTIMIZE = $arg if defined $arg;
     $OPTIMIZE;
 }
 
